from fastapi.responses import HTMLResponse, RedirectResponse
from sqlalchemy.orm import Session
from fastapi import APIRouter, Depends, Request
from fastapi.security import OAuth2PasswordRequestForm
from starlette import status

from app import crud
from app import dependencies
from app import security
from app.dependencies import login_manager


router = APIRouter(prefix="/auth")


@router.post("/login", response_class=HTMLResponse)
def login(
    db: Session = Depends(dependencies.get_db),
    data: OAuth2PasswordRequestForm = Depends(),
):
    username = data.username
    password = data.password
    user = crud.user.get_by_username(db=db, username=username)
    if not user:
        response = RedirectResponse(
            url="/?authenticated=false",
            status_code=status.HTTP_302_FOUND,
        )
        return response
    if not security.check_password(
        plain_password=password,
        hashed_password=user.password,
    ):
        response = RedirectResponse(
            url="/?authenticated=false",
            status_code=status.HTTP_302_FOUND,
        )
        return response

    access_token = login_manager.create_access_token(data={"sub": user.id})
    response = RedirectResponse(
        url="/?authenticated=true",
        status_code=status.HTTP_302_FOUND,
    )
    login_manager.set_cookie(response, access_token)
    return response


@router.get("/logout")
def logout(request: Request, db: Session = Depends(dependencies.get_db)):
    if request.state.user is None:
        return RedirectResponse(
            url="/?authenticated=false",
            status_code=status.HTTP_302_FOUND,
        )

    # TODO:
    # Ensure the cookie is marked as expired via database and ensure that
    # expired cookies cannot be used for authenticated routes.

    response = RedirectResponse(
        url="/?authenticated=false",
        status_code=status.HTTP_302_FOUND,
    )
    login_manager.set_cookie(response, "deleted")
    return response
