from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session

from app import crud
from app.models.user import User
from app.dependencies import authenticated_user, get_db
from app.schemas.chest import Chest as ChestModel

router = APIRouter(prefix="/storage")


@router.get("/chests/{id}", response_model=ChestModel)
def get(
    id: int,
    db: Session = Depends(get_db),
    _: User = Depends(authenticated_user),
) -> ChestModel:
    chest = crud.chest.get(db=db, id=id)
    if not chest:
        raise HTTPException(status_code=404, detail="Chest not found")
    return chest
