from sqlalchemy.orm import Session
from fastapi import APIRouter, Depends

from app import crud
from app.dependencies import authenticated_admin, authenticated_user, get_db
from app.models.user import User
from app.schemas.user import User as UserModel


router = APIRouter(prefix="/users")


@router.get("/me", response_model=UserModel)
def get_me(user: User = Depends(authenticated_user)):
    return user


@router.post("/", response_model=UserModel)
def create(
    id: int, db: Session = Depends(get_db), _: User = Depends(authenticated_admin)
):
    # TODO: User registration is disabled for now, will be implement soon.
    pass


@router.get("/{id}", response_model=UserModel)
def get(id: int, db: Session = Depends(get_db), _: User = Depends(authenticated_admin)):
    return crud.user.get(db=db, id=id)


@router.put("/{id}", response_model=UserModel)
def update(
    id: int, db: Session = Depends(get_db), _: User = Depends(authenticated_admin)
):
    # TODO: User update not implemented yet.
    pass
