import uuid
from typing import List, Optional

from sqlalchemy.sql import func
from sqlalchemy.orm import Session

from app.models.chest import Chest


def get(db: Session, id: int) -> Optional[Chest]:
    return db.query(Chest).get(id)


def get_by_uid(db: Session, uid: str) -> Optional[Chest]:
    return db.query(Chest).filter_by(uid=uid).first()


def get_all_by_user(db: Session, user_id: int) -> List[Chest]:
    return db.query(Chest).filter_by(user_id=user_id).all()


def create(db: Session, picture: str, content: str, user_id: int) -> Chest:
    chest = Chest(
        uid=str(uuid.uuid4()),
        picture=picture,
        content=content,
        user_id=user_id,
    )
    db.add(chest)
    db.commit()
    return chest


def get_random(db: Session, num: int) -> List[Chest]:
    return (
        db.query(Chest)
        .filter(Chest.user_id != 1)
        .order_by(func.random())
        .limit(num)
        .all()
    )
