import os
import json
import random
import secrets
from typing import Sequence

from sqlalchemy.orm import Session

import secrets
from app import crud
from app.config import settings


def _seed_required(db: Session) -> bool:
    try:
        return crud.user.get_by_username(db=db, username="admin") is None
    except Exception:
        pass
    return True


def _seed_storage(db: Session, num: int, usernames: Sequence[str]):
    content_options = (
        "Lots and lots of candy...",
        "Some candy and ... a map?",
        "Half-eaten gummy worms...",
        "Candy parrots",
        "Chocolate coins",
        "Candy cannonballs",
        "Jellyfish jellies",
        "Sour shark teeth",
    )
    pictures = (
        "0.png",
        "1.png",
        "2.png",
        "3.png",
        "4.png",
        "5.png",
        "6.png",
        "7.png",
        "8.png",
        "9.png",
    )
    for index in range(1, num + 1):
        user = crud.user.get_by_username(db=db, username=random.choice(usernames))
        picture = random.choice(pictures)
        content = random.choice(content_options)
        if index == 42:
            if os.environ.get("EXTRA_STORAGE") is not None:
                for extra_storage in json.loads(os.environ["EXTRA_STORAGE"]):
                    crud.chest.create(db=db, **extra_storage)
        else:
            crud.chest.create(
                db=db,
                picture=picture,
                content=content,
                user_id=user.id,
            )

    db.commit()


def _seed_users(db: Session):
    crud.user.create(
        db,
        username="admin",
        password=secrets.token_hex(32),
        is_admin=True,
    )

    # fmt: off
    usernames = (
        "Dodoism", "RoserKalita", "Multisulcate", "Monorchism", "Bracciale",
        "ProseamGlib", "BiddickCrambo", "Caoutchouc", "Tessellate",
        "Calisthenics", "Symmography", "Loggerhead", "Cordovan", "Gossamer",
        "Mumpsimus", "Parasitaster", "Blendure", "Frangipani",
    )
    # fmt: on
    return [
        crud.user.create(
            db=db,
            username=username,
            password=secrets.token_hex(32),
            is_admin=False,
        )
        for username in usernames
    ]


def seed_db(db: Session):
    users = _seed_users(db)
    _seed_storage(
        db, num=50 + (len(users) * 2), usernames=[user.username for user in users]
    )


def init_db(db: Session) -> None:
    from app.db import base  # noqa: F401
    from app.db.base_class import Base

    # Determine if we need to seed the db.
    if not _seed_required(db):
        return

    Base.metadata.create_all(bind=db.get_bind())
    seed_db(db)
    db.commit()
