from fastapi.requests import Request
from fastapi.exceptions import HTTPException
from fastapi_login import LoginManager

from app.config import settings
from app import crud
from app.db.session import SessionLocal


def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()


login_manager = LoginManager(
    settings.SECRET_KEY, token_url="/auth/login", use_cookie=True
)


@login_manager.user_loader()
def load_user(id: int):
    return crud.user.get(db=next(get_db()), id=id)


def authenticated_admin(request: Request):
    user = request.state.user
    if user is None:
        raise HTTPException(401)
    elif not user.is_admin:
        raise HTTPException(401)
    else:
        return user


def authenticated_user(request: Request):
    user = request.state.user
    if user is None:
        raise HTTPException(401)
    else:
        return user
