from fastapi import APIRouter, FastAPI
from fastapi.staticfiles import StaticFiles

from app.config import settings
from app.constants import STATIC_DIR
from app.pages import router as pages
from app.api.auth import router as auth_api
from app.api.user import router as user_api
from app.api.health import router as health_api
from app.api.chest import router as chest_api


app = FastAPI(
    title=settings.APP_TITLE,
    description=settings.APP_DESCRIPTION,
    openapi_url=f"{settings.API_V1_STR}/openapi.json",
)

app.mount("/static", StaticFiles(directory=STATIC_DIR), name="static")
app.include_router(pages, include_in_schema=False)

api_router = APIRouter(prefix=settings.API_V1_STR)
api_router.include_router(health_api)
api_router.include_router(auth_api)
api_router.include_router(user_api)
api_router.include_router(chest_api)
# add more api routers here
app.include_router(api_router)

# Add the login_manager as a middleware
from app.dependencies import login_manager

login_manager.useRequest(app)
